@@ -132,19 +132,6 @@ class Assets:
                         gateway.get_access_endpoint(self._config)
 
                     )]
-        elif metadata_copy['main']['type'] == 'compute':
-            compute_service_attributes = self._build_compute(metadata_copy,
-                                                             publisher_account)
-            if not service_descriptors:
-                service_descriptors = [ServiceDescriptor.compute_service_descriptor(
-                    compute_service_attributes, gateway.get_execute_endpoint(self._config))
-                ]
-            else:
-                service_descriptors += [ServiceDescriptor.compute_service_descriptor(
-                    compute_service_attributes,
-                    gateway.get_execute_endpoint(self._config)
-
-                )]
         else:
             if not service_descriptors:
                 service_descriptors = []
@@ -186,8 +173,8 @@ class Assets:
             elif service.type == ServiceTypes.CLOUD_COMPUTE:
                 compute_service = ServiceFactory.complete_compute_service(
                     did,
-                    gateway.get_execute_endpoint(self._config),
-                    compute_service_attributes,
+                    service.service_endpoint,
+                    service.attributes,
                     self._keeper.compute_execution_condition.address,
                     self._keeper.escrow_reward_condition.address
                 )
@@ -206,7 +193,7 @@ class Assets:
 
         # Setup metadata service
         # First compute files_encrypted
-        if metadata_copy['main']['type'] == 'dataset':
+        if metadata_copy['main']['type'] in ['dataset', 'algorithm']:
             assert metadata_copy['main'][
                 'files'], 'files is required in the metadata main attributes.'
             logger.debug('Encrypting content urls in the metadata.')
@@ -266,6 +253,40 @@ class Assets:
             return None
         return ddo
 
+    def create_compute(self, metadata, publisher_account,
+               service_descriptors=None, providers=None,
+               authorization_type=ServiceAuthorizationTypes.PSK_RSA, use_secret_store=False):
+        """
+        Register a compute to the data asset in both the keeper's DIDRegistry (on-chain) and in
+        the Metadata store.
+
+        :param metadata: dict conforming to the Metadata accepted by Nevermined Protocol.
+        :param publisher_account: Account of the publisher registering this asset
+        :param service_descriptors: list of ServiceDescriptor tuples of length 2.
+            The first item must be one of ServiceTypes and the second
+            item is a dict of parameters and values required by the service
+        :param providers: list of addresses of providers of this asset (a provider is
+            an ethereum account that is authorized to provide asset services)
+        :param authorization_type: str indicate the authorization type that is going to be used
+        to encrypt the urls.
+            SecretStore, PSK-RSA and PSK-ECDSA are supported.
+        :param use_secret_store: bool indicate whether to use the secret store directly for
+            encrypting urls (Uses Gateway provider service if set to False)
+        :return: DDO instance
+        """
+
+        metadata_copy = copy.deepcopy(metadata)
+        gateway = GatewayProvider.get_gateway()
+
+        compute_service_attributes = self._build_compute(metadata_copy, publisher_account)
+        service_descriptor = ServiceDescriptor.compute_service_descriptor(
+            compute_service_attributes, gateway.get_execute_endpoint(self._config))
+
+        return self.create(metadata, publisher_account, service_descriptors=[service_descriptor],
+            providers=providers, authorization_type=authorization_type,
+            use_secret_store=use_secret_store)
+
+
     def retire(self, did):
         """
         Retire this did of Metadata
@@ -391,7 +412,7 @@ class Assets:
         if index is not None:
             assert isinstance(index, int), logger.error('index has to be an integer.')
             assert index >= 0, logger.error('index has to be 0 or a positive integer.')
-        return self._asset_consumer.download(
+        return self._asset_consumer.access(
             service_agreement_id,
             service_index,
             ddo,
@@ -402,6 +423,39 @@ class Assets:
             index
         )
 
+    def download(self, did, service_index, owner_account, destination, index=None):
+        """
+        Download the asset data.
+
+        Using the service endpoint defined in the ddo's service pointed to by service_definition_id.
+        Consumer's permissions is checked implicitly by the secret-store during decryption
+        of the contentUrls.
+        The service endpoint is expected to also verify that `owner_account` is the actual owner
+        of the asset.
+        This method downloads and saves the asset datafiles to disk.
+
+        :param did: DID, str
+        :param service_index: identifier of the service inside the asset DDO, str
+        :param owner_account: Account instance of the owner
+        :param destination: str path
+        :param index: Index of the document that is going to be downloaded, int
+        :return: str path to saved files
+        """
+        ddo = self.resolve(did)
+        if index is not None:
+            assert isinstance(index, int), logger.error('index has to be an integer.')
+            assert index >= 0, logger.error('index has to be 0 or a positive integer.')
+        return self._asset_consumer.download(
+            service_index,
+            ddo,
+            owner_account,
+            destination,
+            GatewayProvider.get_gateway(),
+            self._get_secret_store(owner_account),
+            self._config,
+            index
+        )
+
     def validate(self, metadata):
         """
         Validate that the metadata is ok to be stored in Metadata.
