@@ -8,8 +8,8 @@ from common_utils_py.did import DID
 from contracts_lib_py.exceptions import DIDNotFound
 from contracts_lib_py.web3_provider import Web3Provider
 
-from tests.resources.helper_functions import (get_algorithm_ddo, get_computing_metadata,
-                                              get_workflow_ddo, log_event)
+from tests.resources.helper_functions import (get_algorithm_ddo, get_workflow_ddo,
+                                              log_event, get_metadata)
 
 
 def create_asset(publisher_instance, ddo_sample):
@@ -268,8 +268,8 @@ def test_assets_workflow(publisher_instance):
 
 def test_assets_compute(publisher_instance):
     publisher = publisher_instance.main_account
-    metadata = get_computing_metadata()
-    ddo = publisher_instance.assets.create(metadata, publisher)
+    metadata = get_metadata()
+    ddo = publisher_instance.assets.create_compute(metadata, publisher)
     assert ddo
     publisher_instance.assets.retire(ddo.did)
 
@@ -302,8 +302,8 @@ def test_execute_workflow(publisher_instance, consumer_instance):
     metadata = get_workflow_ddo()['service'][0]
     workflow_ddo = publisher_instance.assets.create(metadata['attributes'], publisher)
     assert workflow_ddo
-    metadata = get_computing_metadata()
-    ddo_computing = publisher_instance.assets.create(metadata, publisher)
+    metadata = get_metadata()
+    ddo_computing = publisher_instance.assets.create_compute(metadata, publisher)
     assert ddo_computing
     service = ddo_computing.get_service(service_type=ServiceTypes.CLOUD_COMPUTE)
     sa = ServiceAgreement.from_service_dict(service.as_dictionary())
@@ -314,21 +314,21 @@ def test_execute_workflow(publisher_instance, consumer_instance):
     publisher_instance.assets.retire(workflow_ddo.did)
 
 
-def test_agreement_direct(publisher_instance_no_init, consumer_instance_no_init, metadata):
-    publisher_account = publisher_instance_no_init.main_account
-    consumer_account = consumer_instance_no_init.main_account
-    ddo = publisher_instance_no_init.assets.create(metadata, publisher_account,
+def test_agreement_direct(publisher_instance, consumer_instance, metadata):
+    publisher_account = publisher_instance.main_account
+    consumer_account = consumer_instance.main_account
+    ddo = publisher_instance.assets.create(metadata, publisher_account,
                                                    providers=[
                                                        '0x068Ed00cF0441e4829D9784fCBe7b9e26D4BD8d0'])
 
-    agreement_id = consumer_instance_no_init.assets.order_direct(ddo.did,
+    agreement_id = consumer_instance.assets.order_direct(ddo.did,
                                                                  ServiceTypesIndices.DEFAULT_ACCESS_INDEX,
                                                                  consumer_account,
                                                                  consumer_account
                                                                  )
-    assert publisher_instance_no_init.agreements.status(agreement_id)
+    assert publisher_instance.agreements.status(agreement_id)
 
-    keeper = publisher_instance_no_init.keeper
+    keeper = publisher_instance.keeper
 
     event = keeper.lock_reward_condition.subscribe_condition_fulfilled(
         agreement_id,
@@ -339,6 +339,6 @@ def test_agreement_direct(publisher_instance_no_init, consumer_instance_no_init,
     )
     assert event, 'no event for LockRewardCondition.Fulfilled'
 
-    assert publisher_instance_no_init.agreements.is_access_granted(agreement_id, ddo.did,
+    assert publisher_instance.agreements.is_access_granted(agreement_id, ddo.did,
                                                                    consumer_account.address)
-    publisher_instance_no_init.assets.retire(ddo.did)
+    publisher_instance.assets.retire(ddo.did)
