@@ -9,9 +9,12 @@ from urllib.request import urlopen
 import coloredlogs
 import yaml
 from common_utils_py.ddo.ddo import DDO
+from common_utils_py.http_requests.requests_session import get_requests_session
 from contracts_lib_py.utils import get_account
 
 from nevermined_sdk_py.gateway.gateway_provider import GatewayProvider
+from nevermined_sdk_py.gateway.gateway import Gateway
+from nevermined_sdk_py.secret_store.secret_store import SecretStore
 from nevermined_sdk_py.nevermined.keeper import NeverminedKeeper as Keeper
 from nevermined_sdk_py.nevermined.nevermined import Nevermined
 from nevermined_sdk_py.secret_store.secret_store_provider import SecretStoreProvider
@@ -55,8 +58,13 @@ def get_publisher_instance(init_tokens=True, use_ss_mock=True, use_gateway_mock=
         init_ocn_tokens(nevermined, nevermined.main_account)
     if use_ss_mock:
         SecretStoreProvider.set_secret_store_class(SecretStoreMock)
+    else:
+        SecretStoreProvider.set_secret_store_class(SecretStore)
     if use_gateway_mock:
         GatewayProvider.set_gateway_class(GatewayMock)
+    else:
+        Gateway.set_http_client(get_requests_session())
+        GatewayProvider.set_gateway_class(Gateway)
 
     return nevermined
 
@@ -69,8 +77,13 @@ def get_consumer_instance(init_tokens=True, use_ss_mock=True, use_gateway_mock=T
         init_ocn_tokens(nevermined, nevermined.main_account)
     if use_ss_mock:
         SecretStoreProvider.set_secret_store_class(SecretStoreMock)
+    else:
+        SecretStoreProvider.set_secret_store_class(SecretStore)
     if use_gateway_mock:
         GatewayProvider.set_gateway_class(GatewayMock)
+    else:
+        Gateway.set_http_client(get_requests_session())
+        GatewayProvider.set_gateway_class(Gateway)
 
     return nevermined
 
@@ -85,30 +98,30 @@ def get_assset_json_text(url):
 
 def get_ddo_sample():
     return _get_asset(
-        "https://raw.githubusercontent.com/keyko-io/nevermined-docs/master/architecture/specs/examples/metadata/v0.1/ddo-example-access.json")
+        "https://raw.githubusercontent.com/keyko-io/nevermined-docs/master/docs/architecture/specs/examples/metadata/v0.1/ddo-example-access.json")
 
 
 def get_algorithm_ddo():
     return json.loads(urlopen(
-        "https://raw.githubusercontent.com/keyko-io/nevermined-docs/master/architecture/specs/examples/metadata/v0.1/ddo-example-algorithm.json").read().decode(
+        "https://raw.githubusercontent.com/keyko-io/nevermined-docs/master/docs/architecture/specs/examples/metadata/v0.1/ddo-example-algorithm.json").read().decode(
         'utf-8'))
 
 
 def get_workflow_ddo():
     return json.loads(urlopen(
-        "https://raw.githubusercontent.com/keyko-io/nevermined-docs/master/architecture/specs/examples/metadata/v0.1/ddo-example-workflow.json").read().decode(
+        "https://raw.githubusercontent.com/keyko-io/nevermined-docs/master/docs/architecture/specs/examples/metadata/v0.1/ddo-example-workflow.json").read().decode(
         'utf-8'))
 
 
 def get_computing_metadata():
     return json.loads(urlopen(
-        'https://raw.githubusercontent.com/keyko-io/nevermined-docs/master/architecture/specs/examples/metadata/v0.1/computing-metadata.json').read().decode(
+        'https://raw.githubusercontent.com/keyko-io/nevermined-docs/master/docs/architecture/specs/examples/metadata/v0.1/computing-metadata.json').read().decode(
         'utf-8'))
 
 
 def get_computing_ddo():
     return _get_asset(
-        "https://raw.githubusercontent.com/keyko-io/nevermined-docs/master/architecture/specs/examples/compute/v0.1/ddo.computing.json")
+        "https://raw.githubusercontent.com/keyko-io/nevermined-docs/master/docs/architecture/specs/examples/compute/v0.1/ddo.computing.json")
 
 
 def get_registered_ddo(nevermined_instance, account):
@@ -142,7 +155,7 @@ def get_rsa_public_key_file():
 
 def get_metadata():
     return json.loads(urlopen(
-        "https://raw.githubusercontent.com/keyko-io/nevermined-docs/master/architecture/specs"
+        "https://raw.githubusercontent.com/keyko-io/nevermined-docs/master/docs/architecture/specs"
         "/examples/metadata/v0.1/metadata1.json").read().decode(
         'utf-8'))
 
